import aiohttp
from .get_host import _host

async def ping():
    try:
        async with aiohttp.request("GET", _host()) as r:
            if r.status == 200:
                print("online")
            else:
                print("offline", r.status)
    except Exception as e:
         print("Connection failed.", e)


from apscheduler.schedulers.asyncio import AsyncIOScheduler

scheduler = AsyncIOScheduler()

class dolphin:
    def add_job(ping, seconds=600):
        scheduler.add_job(ping, "interval", seconds=seconds)
    def swim():
        scheduler.start()
        print("swimming...")


import setuptools


with open("README.md", "r") as setup:
    long_description = setup.read()

setuptools.setup(
    name="pydolphin",
    version="0.1.1",
    author="Dhruv Maaniya (@midnightmadwalk)",
    author_email="midnightmadwalk@gmail.com",
    description="a convenient solution to heroku web apps / APIs.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/dolphinorg/dolphin",
    license="MIT",
    packages=setuptools.find_packages(),
    include_package_data=True,
    install_requires=['aiohttp', 'apscheduler'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)



import os
from flask import Flask
from pydolphin import dolphin



app = Flask(__name__)

@app.before_first_request
def dolphin_start():
    dolphin.swim()

@app.route('/')
def index():
    return 'hello'

port = int(os.environ.get("PORT", 6969))
app.run(host='0.0.0.0', port=port)
